---
# https://vitepress.dev/reference/default-theme-home-page
layout: home

hero:
  name: "ingestr"
  text: Copy data between any source and any destination
  tagline: "ingestr is a command-line application that allows ingesting or copying data from any source into any destination database."
  actions:
    - theme: brand
      text: Getting Started
      link: /getting-started/quickstart.md
    - theme: alt
      text: GitHub
      link: https://github.com/bruin-data/ingestr

features:
  - title: Feature A
    details: Lorem ipsum dolor sit amet, consectetur adipiscing elit
  - title: Feature B
    details: Lorem ipsum dolor sit amet, consectetur adipiscing elit
  - title: Feature C
    details: Lorem ipsum dolor sit amet, consectetur adipiscing elit
---

